package data.scripts.world;

import java.util.*;

import com.fs.starfarer.api.EveryFrameScript;
import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.campaign.CampaignClockAPI;
import com.fs.starfarer.api.campaign.CampaignFleetAPI;
import com.fs.starfarer.api.campaign.LocationAPI;
import com.fs.starfarer.api.campaign.SectorAPI;
import com.fs.starfarer.api.campaign.SectorEntityToken;
import com.fs.starfarer.api.campaign.SpawnPointPlugin;

@SuppressWarnings("unchecked")
public abstract class BaseSpawnPoint implements EveryFrameScript, SpawnPointPlugin {

    protected float daysInterval;
    private final int maxFleets;
    private final SectorEntityToken anchor;

    private final List<CampaignFleetAPI> fleets = new ArrayList<>();
    private long lastSpawnTime = Long.MIN_VALUE;

    private final SectorAPI sector;
    private final LocationAPI location;

    public BaseSpawnPoint(SectorAPI sector, LocationAPI location, float daysInterval, int maxFleets, SectorEntityToken anchor) {
        this.daysInterval = daysInterval;
        this.maxFleets = maxFleets;
        this.anchor = anchor;
        this.sector = sector;
        this.location = location;

        lastSpawnTime = Global.getSector().getClock().getTimestamp();
    }

    /* 
     * Included only for backwards compatibility with some test saves.
     */
    @Override
    public void advance(SectorAPI sector, LocationAPI location) {
        advance(0f);
    }

    @Override
    public void advance(float amount) {
        CampaignClockAPI clock = sector.getClock();

        if (clock.getElapsedDaysSince(lastSpawnTime) >= daysInterval) {
            lastSpawnTime = clock.getTimestamp();

            Iterator<CampaignFleetAPI> iter = fleets.iterator();
            while (iter.hasNext()) {
                CampaignFleetAPI fleet = iter.next();
                if (!fleet.isAlive()) {
                    iter.remove();
                }
            }

            if (fleets.size() < maxFleets) {
                CampaignFleetAPI fleet = spawnFleet();
                if (fleet != null) {
                    fleets.add(fleet);
                }
            }
        }
    }

    @Override
    public boolean isDone() {
        return false;
    }

    @Override
    public boolean runWhilePaused() {
        return false;
    }

    public float getDaysInterval() {
        return daysInterval;
    }

    public int getMaxFleets() {
        return maxFleets;
    }

    public SectorEntityToken getAnchor() {
        return anchor;
    }

    public List<CampaignFleetAPI> getFleets() {
        return fleets;
    }

    public long getLastSpawnTime() {
        return lastSpawnTime;
    }

    public SectorAPI getSector() {
        return sector;
    }

    public LocationAPI getLocation() {
        return location;
    }

    protected abstract CampaignFleetAPI spawnFleet();

}
