package data.scripts.world.citadel;

import java.util.List;

import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.campaign.CampaignFleetAPI;
import com.fs.starfarer.api.campaign.CargoAPI;
import com.fs.starfarer.api.campaign.FleetAssignment;
import com.fs.starfarer.api.campaign.JumpPointAPI;
import com.fs.starfarer.api.campaign.LocationAPI;
import com.fs.starfarer.api.campaign.OrbitAPI;
import com.fs.starfarer.api.campaign.SectorAPI;
import com.fs.starfarer.api.campaign.SectorEntityToken;
import com.fs.starfarer.api.campaign.StarSystemAPI;
import com.fs.starfarer.api.campaign.CargoAPI.CrewXPLevel;
import com.fs.starfarer.api.campaign.PlanetAPI;
import com.fs.starfarer.api.campaign.econ.EconomyAPI;
import com.fs.starfarer.api.campaign.econ.MarketAPI;
import com.fs.starfarer.api.fleet.FleetMemberType;
import com.fs.starfarer.api.impl.campaign.ids.Conditions;
import com.fs.starfarer.api.impl.campaign.ids.Factions;
import com.fs.starfarer.api.impl.campaign.ids.Submarkets;
import com.fs.starfarer.api.impl.campaign.submarkets.StoragePlugin;
import java.awt.Color;
import java.util.ArrayList;
import java.util.Arrays;

public class Citadel {

    public void generate(SectorAPI sector) {

        String CITADEL_FACTION = "citadeldefenders";

        //MAIN SYSTEM AND STAR
        
        StarSystemAPI system = sector.createStarSystem("Citadel");
        system.getLocation().set(-10000, 3000);
        system.setBackgroundTextureFilename("graphics/backgrounds/background2.jpg");

        PlanetAPI blaze = system.initStar("blaze", "star_blue", 250f);
        blaze.setCustomDescriptionId("citadel_blaze");
        
        //GATEWAY
        
        PlanetAPI gateway = system.addPlanet("gateway", blaze, "Gateway", "arid", 0, 100, 1000, 381);
        gateway.setCustomDescriptionId("citadel_gateway");
        gateway.setFaction("citadeldefenders");
        
        //TETRIS
        
        PlanetAPI tetris = system.addPlanet("tetris", blaze, "Tetris", "toxic", 180, 220, 6000, 222);
        tetris.setCustomDescriptionId("citadel_tetris");
        tetris.setFaction("independent");
        
        //CITADEL PRIME

        PlanetAPI citadel_prime = system.addPlanet("citadelprime", blaze, "Citadel Prime", "terran", 360, 160, 4000, 381);
        citadel_prime.setCustomDescriptionId("citadel_citadelprime");
        citadel_prime.setInteractionImage("illustrationz", "twin_cities");
        citadel_prime.setFaction("citadeldefenders");
        
        //RINGS/ASTEROID BELTS

        system.addAsteroidBelt(blaze, 600, 9000, 1400, 600, 400);
        system.addRingBand(blaze, "misc", "rings1", 256f, 2, Color.WHITE, 256f, 9000, 400);
        system.addRingBand(blaze, "misc", "rings1", 256f, 2, Color.LIGHT_GRAY, 256f, 9050, 400);
        system.setLightColor(new Color(24,168,209));

        //ABANDONDED STATION
        
        SectorEntityToken neutralStation = system.addOrbitalStation("citadel_abandoned_station", system.getEntityById("Gateway"), 155, 200, 53, "Abandoned Orbital Customs", "neutral");
        neutralStation.getMemory().set("$abandonedStation", true);
        MarketAPI market = Global.getFactory().createMarket("citadel_abandoned_station_market", neutralStation.getName(), 0);
        market.setPrimaryEntity(neutralStation);
        market.setFactionId(neutralStation.getFaction().getId());
        market.addCondition(Conditions.ABANDONED_STATION);
        market.addSubmarket(Submarkets.SUBMARKET_STORAGE);
        ((StoragePlugin) market.getSubmarket(Submarkets.SUBMARKET_STORAGE).getPlugin()).setPlayerPaidToUnlock(true);
        neutralStation.setMarket(market);
        neutralStation.setCustomDescriptionId("citadel_gateway_station");
        neutralStation.setInteractionImage("illustrations", "abandoned_station");

        //CITADEL STATION
        
        SectorEntityToken foxShipyards = system.addCustomEntity("citadelprime_station", "Citadel Orbital Complex", "station_citadel_type", "citadeldefenders");
        //again, setting an orbit for this new station we made
        foxShipyards.setCircularOrbitPointingDown(system.getEntityById("citadelprime"), 25, 400, 50);
        foxShipyards.setInteractionImage("illustrationz", "streets");
        foxShipyards.setCustomDescriptionId("citadel_station");

        //INDIE STATION
        
        SectorEntityToken foxBase = system.addCustomEntity("citadel_indie_station", "Refugee Station", "station_side04", "independent");
        //again, setting an orbit for this new station we made
        foxBase.setCustomDescriptionId("citadel_tetris_station");
        foxBase.setCircularOrbitPointingDown(system.getEntityById("Tetris"), 45, 400, 50);

        //PIRATE STATION
        
        SectorEntityToken pirateStation = system.addCustomEntity("citadel_pirate_station",
                "Hidden Pirate Base", "station_pirate_type", "pirates");
        pirateStation.setCircularOrbit(system.getEntityById("blaze"), 1400, 9500, 400);
        pirateStation.setCustomDescriptionId("citadel_pirate_station");
        pirateStation.setInteractionImage("illustrations", "pirate_station");

        //RELAYS
        SectorEntityToken relay = system.addCustomEntity("citadel_relay", // unique id
                "Citadel Relay", // name - if null, defaultName from custom_entities.json will be used
                "comm_relay", // type of object, defined in custom_entities.json
                "citadeldefenders"); // faction
        relay.setCircularOrbit(system.getEntityById("citadelprime"), 90, 650, 80);

        //HYPERSPACE POINTS
        //this makes the variable "hyper" the location of the starsystem we defined in defendersGen
        LocationAPI hyper = Global.getSector().getHyperspace();

//defining the term citadel3 to be Citadel Prime
        SectorEntityToken citadel3 = system.getEntityById("citadelprime");
        JumpPointAPI jumpPoint = Global.getFactory().createJumpPoint("Citadel_gate", "Citadel Gate");
        //the two lines below are in charge of setting jumpPoint's orbit
        OrbitAPI orbit = Global.getFactory().createCircularOrbit(citadel3, 0, 500, 30);
        jumpPoint.setOrbit(orbit);
        //tells the game that this jumppoint is with Citadel Prime
        jumpPoint.setRelatedPlanet(citadel3);
        //makes it look like a wormhole
        jumpPoint.setStandardWormholeToHyperspaceVisual();
        //this line actually puts the damn thing in
        system.addEntity(jumpPoint);
        //this makes a fringe jump point for us
        system.autogenerateHyperspaceJumpPoints(true, true);

        //ABANDONED STATION
        //add markets
        //Gateway market
        addMarketplace(CITADEL_FACTION,
                gateway,
                null,
                "Gateway",
                3,
                new ArrayList<>(Arrays.asList(Conditions.DESERT, Conditions.ORE_COMPLEX, Conditions.POPULATION_1)),
                new ArrayList<>(Arrays.asList(Submarkets.SUBMARKET_BLACK, Submarkets.SUBMARKET_OPEN)),
                0.3f
        );

        //Add pirate station market
        addMarketplace(Factions.PIRATES,
                pirateStation,
                null,
                "Hidden Pirate Base",
                7,
                new ArrayList<>(Arrays.asList(Conditions.ORE_COMPLEX, Conditions.FREE_PORT, Conditions.ORBITAL_STATION, Conditions.OUTPOST, Conditions.UNINHABITABLE, Conditions.VICE_DEMAND, Conditions.POPULATION_2, Conditions.ORGANIZED_CRIME)),
                new ArrayList<>(Arrays.asList(Submarkets.SUBMARKET_OPEN, Submarkets.SUBMARKET_BLACK)),
                0.3f
        );

        addMarketplace(CITADEL_FACTION,
                citadel_prime,
                new ArrayList<>(Arrays.asList(foxShipyards)),
                "Citadel Prime",
                9,
                new ArrayList<>(Arrays.asList(Conditions.LARGE_REFUGEE_POPULATION, Conditions.ORBITAL_STATION, Conditions.ORE_REFINING_COMPLEX, Conditions.LIGHT_INDUSTRIAL_COMPLEX, Conditions.AUTOFAC_HEAVY_INDUSTRY, Conditions.TERRAN, Conditions.TRADE_CENTER, Conditions.POPULATION_6, Conditions.REGIONAL_CAPITAL, Conditions.URBANIZED_POLITY, Conditions.MILITARY_BASE)),
                new ArrayList<>(Arrays.asList(Submarkets.GENERIC_MILITARY, Submarkets.SUBMARKET_STORAGE, Submarkets.SUBMARKET_BLACK, Submarkets.SUBMARKET_OPEN)),
                0.3f
        );

        addMarketplace(Factions.INDEPENDENT,
                tetris,
                new ArrayList<>(Arrays.asList(foxBase)),
                "Tetris",
                5,
                new ArrayList<>(Arrays.asList(Conditions.DISSIDENT, Conditions.UNINHABITABLE, Conditions.POPULATION_3, Conditions.LARGE_REFUGEE_POPULATION, Conditions.LIGHT_INDUSTRIAL_COMPLEX, Conditions.LIGHT_INDUSTRIAL_COMPLEX, Conditions.VICE_DEMAND)),
                new ArrayList<>(Arrays.asList(Submarkets.GENERIC_MILITARY, Submarkets.SUBMARKET_STORAGE, Submarkets.SUBMARKET_BLACK, Submarkets.SUBMARKET_OPEN)),
                0.3f
        );
    }

    private void spawnCDDF(SectorAPI sector, StarSystemAPI system, SectorEntityToken location) {
        CampaignFleetAPI fleet = sector.createFleet("citadeldefenders", "defendersdefenseFleet");
        /*
         try {
         FleetManager.createFleet(fleet, "CIT_" + "defendersdefenseFleet"); // Use the SS+ faction prefix plus the internal faction name, such as HEG_systemDefense
         } catch (NoClassDefFoundError ex) {
         // Other randomization method here, if any; otherwise, vanilla method will be used
         }
         */
        system.spawnFleet(location, -500, 200, fleet);

        fleet.addAssignment(FleetAssignment.DEFEND_LOCATION, location, 1000000);
        fleet.setPreferredResupplyLocation(location);

    }

    private void initFoxCargo(SectorAPI sector, SectorEntityToken station) {
        CargoAPI defenderscargo = station.getCargo();

        defenderscargo.addCrew(CrewXPLevel.VETERAN, 250);
        defenderscargo.addCrew(CrewXPLevel.GREEN, 500);
        defenderscargo.addCrew(CrewXPLevel.REGULAR, 400);
        defenderscargo.addCrew(CrewXPLevel.ELITE, 100);
        defenderscargo.addMarines(100);
        defenderscargo.addSupplies(500);
        defenderscargo.addFuel(750);

        defenderscargo.addWeapons("dualflak", 20);
        defenderscargo.addWeapons("swarmer", 15);
        defenderscargo.addWeapons("sabotpod", 5);
        defenderscargo.addWeapons("pdburst", 10);
        defenderscargo.addWeapons("heatseeker", 5);
        defenderscargo.addWeapons("annihilator", 10);
        defenderscargo.addWeapons("irpulse", 10);
        defenderscargo.addWeapons("heavyneedler", 20);
        defenderscargo.addWeapons("heavymauler", 20);
        defenderscargo.addWeapons("tachyonlance", 5);
        defenderscargo.addWeapons("typhoon", 10);
        defenderscargo.addWeapons("lightneedler", 15);
        defenderscargo.addWeapons("hurricane", 5);
        defenderscargo.addWeapons("harpoon_single", 20);
        defenderscargo.addWeapons("harpoonpod", 5);
        defenderscargo.addWeapons("harpoon", 10);
        defenderscargo.addWeapons("atropos_single", 10);
        defenderscargo.addWeapons("autopulse", 5);
        defenderscargo.addWeapons("arbalest", 10);
        defenderscargo.addWeapons("lightag", 10);
        defenderscargo.addWeapons("lightac", 10);
        defenderscargo.addWeapons("lightdualac", 10);
        defenderscargo.addWeapons("lightdualmg", 20);
        defenderscargo.addWeapons("vulcan", 20);
        defenderscargo.addWeapons("lightmortar", 20);
        defenderscargo.addWeapons("heavyblaster", 10);

        defenderscargo.addWeapons("fox_kineticcpl", 5);
        defenderscargo.addWeapons("fox_antifrigatelaser", 5);
        defenderscargo.addWeapons("fox_seigelaser", 5);
        defenderscargo.addWeapons("fox_zeus", 5);
        defenderscargo.addWeapons("fox_rotunda_large", 5);
        defenderscargo.addWeapons("fox_torpedo_large", 5);

        defenderscargo.addWeapons("fox_ionrepeater", 10);
        defenderscargo.addWeapons("fox_striker", 10);
        defenderscargo.addWeapons("fox_cobra", 10);
        defenderscargo.addWeapons("fox_rotunda", 10);
        defenderscargo.addWeapons("fox_hypermatter", 10);
        defenderscargo.addWeapons("fox_esniper", 10);
        defenderscargo.addWeapons("fox_flak", 10);
        defenderscargo.addWeapons("fox_torpedo", 10);

        defenderscargo.addWeapons("fox_miniflak", 20);
        defenderscargo.addWeapons("fox_meteor", 20);
        defenderscargo.addWeapons("fox_lightacel", 20);
        defenderscargo.addWeapons("fox_copperhead", 20);
        defenderscargo.addWeapons("fox_viper", 20);
        defenderscargo.addWeapons("fox_plasmathrower_small", 20);
        defenderscargo.addWeapons("fox_kbarrage", 20);
        defenderscargo.addWeapons("fox_ebarrage", 20);
        defenderscargo.addWeapons("fox_pd2", 20);
        defenderscargo.addWeapons("fox_ksupportmissile", 20);
        defenderscargo.addWeapons("fox_torpedo_large", 20);
        addRandomWeapons(defenderscargo, 35);

        defenderscargo.initMothballedShips("citadeldefenders");

        //Frigates
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Corvette_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Corvette_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Corvette_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Corvette_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Drone_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Drone_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Drone_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_dfrigate_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_dfrigate_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_dfrigate_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Frigate_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Frigate_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Strike_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Strike_Hull"));

        //Destroyers
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_catamaran_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_catamaran_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_catamaran_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_catamaran_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Minelayer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Minelayer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Minelayer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Minelayer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_LDestroyer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_LDestroyer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_LDestroyer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_LDestroyer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_MDestroyer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_MDestroyer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_MDestroyer_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Battleship_Hull"));

        //Cruisers
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Carrier_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Carrier_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Carrier_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Cruiser_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Cruiser_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Cruiser_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Cruiser_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Tank_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Tank_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Tank_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Tank_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Seige_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Seige_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Seige_Hull"));

        //Capitals
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Battlecruiser_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Battlecruiser_Hull"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.SHIP, "Fox_Dreadnaught_Hull"));

        //Fighters
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_arrowhead_wing"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_arrowhead_wing"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_arrowhead_wing"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_arrowhead_wing"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_arrowhead_wing"));

        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_firewall_wing"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_firewall_wing"));

        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_bomber_torp_wing"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_bomber_torp_wing"));

        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_bomber_plasma_wing"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_bomber_plasma_wing"));

        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_heak_wing"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_heak_wing"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_heak_wing"));

        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_mako_wing"));
        defenderscargo.getMothballedShips().addFleetMember(Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, "fox_mako_wing"));
    }

     public static MarketAPI addMarketplace(String factionID, SectorEntityToken primaryEntity, ArrayList<SectorEntityToken> connectedEntities, String name,
                                           int size, ArrayList<String> marketConditions, ArrayList<String> submarkets, float tarrif) {
        EconomyAPI globalEconomy = Global.getSector().getEconomy();
        String planetID = primaryEntity.getId();
        String marketID = planetID + "_market";

        MarketAPI newMarket = Global.getFactory().createMarket(marketID, name, size);
        newMarket.setFactionId(factionID);
        newMarket.setPrimaryEntity(primaryEntity);
        newMarket.setBaseSmugglingStabilityValue(0);
        newMarket.getTariff().modifyFlat("generator", tarrif);

        if (null != submarkets) {
            for (String market : submarkets) {
                newMarket.addSubmarket(market);
            }
        }

        for (String condition : marketConditions) {
            newMarket.addCondition(condition);
        }

        if (null != connectedEntities) {
            for (SectorEntityToken entity : connectedEntities) {
                newMarket.getConnectedEntities().add(entity);
            }
        }

        globalEconomy.addMarket(newMarket);
        primaryEntity.setMarket(newMarket);
        primaryEntity.setFaction(factionID);

        if (null != connectedEntities) {
            for (SectorEntityToken entity : connectedEntities) {
                entity.setMarket(newMarket);
                entity.setFaction(factionID);
            }
        }

        return newMarket;
    }
     
     	private void addRandomWeapons(CargoAPI cargo, int count) {
		List weaponIds = Global.getSector().getAllWeaponIds();
		for (int i = 0; i < count; i++) {
			String weaponId = (String) weaponIds.get((int) (weaponIds.size() * Math.random()));
			int quantity = (int)(Math.random() * 12f + 2f);
			cargo.addWeapons(weaponId, quantity);
		}
	}

}
